searchData={"content_type":"text/markdown","items":[{"doc":"A collection of formatters and utilities for JSON-based logging for various cloud tools and platforms.","ref":"GSMLG.Logger.html","title":"GSMLG.Logger","type":"module"},{"doc":"* `GSMLG.Logger.Formatters.Basic` - a basic JSON formatter that logs messages in a structured format,\ncan be used with any JSON-based logging system, like ElasticSearch, Logstash, etc.\n\n* `GSMLG.Logger.Formatters.GoogleCloud` - a formatter that logs messages in a structured format that can be\nconsumed by Google Cloud Logger and Google Cloud Error Reporter.\n\n* `GSMLG.Logger.Formatters.Datadog` - a formatter that logs messages in a structured format that can be consumed\nby Datadog.\n\n* `GSMLG.Logger.Formatters.Elastic` - a formatter that logs messages in a structured format that conforms to the\n[Elastic Common Schema (ECS)](https://www.elastic.co/guide/en/ecs/8.11/ecs-reference.html),\nso it can be consumed by ElasticSearch, LogStash, FileBeat and Kibana.","ref":"GSMLG.Logger.html#module-supported-formatters","title":"Supported formatters - GSMLG.Logger","type":"module"},{"doc":"Add `gsmlg_logger` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        # ...\n        {:gsmlg_logger, \"~> 1.0\"}\n        # ...\n      ]\n    end\n\nand install it running `mix deps.get`.\n\nThen, enable the formatter in your `config.exs`:\n\n    config :logger, :default_handler,\n      formatter: {GSMLG.Logger.Formatters.Basic, []}\n\nor during runtime (eg. in your `application.ex`):\n\n    :logger.update_handler_config(:default, :formatter, {Basic, %{}})","ref":"GSMLG.Logger.html#module-installation","title":"Installation - GSMLG.Logger","type":"module"},{"doc":"Configuration can be set using 2nd element of the tuple of the `:formatter` option in `Logger` configuration.\nFor example in `config.exs`:\n\n    config :logger, :default_handler,\n      formatter: {GSMLG.Logger.Formatters.GoogleCloud, metadata: :all, project_id: \"logger-101\"}\n\nor during runtime:\n\n    :logger.update_handler_config(:default, :formatter, {Basic, %{metadata: {:all_except, [:conn]}}})","ref":"GSMLG.Logger.html#module-configuration","title":"Configuration - GSMLG.Logger","type":"module"},{"doc":"Some formatters require additional configuration options. Here are the options that are common for each formatter:\n\n  * `:encoder_opts` - options to be passed directly to the JSON encoder. This allows you to customize the behavior of the JSON\n  encoder. See the [documentation for Jason](https://hexdocs.pm/jason/Jason.html#encode/2-options) for available options. By\n  default, no options are passed to the encoder.\n\n  * `:metadata` - a list of metadata keys to include in the log entry. By default, no metadata is included.\n  If `:all`is given, all metadata is included. If `{:all_except, keys}` is given, all metadata except\n  the specified keys is included. If `{:from_application_env, {app, module}, path}` is given, the metadata is fetched from\n  the application environment (eg. `{:from_application_env, {:logger, :default_formatter}, [:metadata]}`) on each logged message.\n\n  * `:redactors` - a list of tuples, where first element is the module that implements the `GSMLG.Logger.Redactor` behaviour,\n  and the second element is the options to pass to the redactor module. By default, no redactors are used.","ref":"GSMLG.Logger.html#module-shared-options","title":"Shared Options - GSMLG.Logger","type":"module"},{"doc":"You can set some well-known metadata keys to be included in the log entry. The following keys are supported\nfor all formatters:\n\n  * `:conn` - the `Plug.Conn` struct, setting it will include the request and response details in the log entry;\n  * `:crash_reason` - a tuple where the first element is the exception struct and the second is the stacktrace.\n  For example: `Logger.error(\"Exception!\", crash_reason: {e, __STACKTRACE__})`. Setting it will include the exception\n  details in the log entry.\n\nFormatters may encode the well-known metadata differently and support additional metadata keys, see the documentation\nof the formatter for more details.","ref":"GSMLG.Logger.html#module-metadata","title":"Metadata - GSMLG.Logger","type":"module"},{"doc":"Changes Logger log level at runtime.\n\nNotice that settings this value below `compile_time_purge_level` would not work,\nbecause Logger calls would be already stripped at compile-time.","ref":"GSMLG.Logger.html#configure_log_level!/1","title":"GSMLG.Logger.configure_log_level!/1","type":"function"},{"doc":"Configures Logger log level at runtime by using value from environment variable.\n\nBy default, 'LOG_LEVEL' environment variable is used.","ref":"GSMLG.Logger.html#configure_log_level_from_env!/1","title":"GSMLG.Logger.configure_log_level_from_env!/1","type":"function"},{"doc":"A telemetry handler that logs Ecto query metrics in JSON format.\n\nThis module is not recommended to be used in production, as it can be\ncostly to log every single database query.","ref":"GSMLG.Logger.Ecto.html","title":"GSMLG.Logger.Ecto","type":"module"},{"doc":"Attaches the telemetry handler to the given event.","ref":"GSMLG.Logger.Ecto.html#attach/3","title":"GSMLG.Logger.Ecto.attach/3","type":"function"},{"doc":"* `:level` - log level which is used to log requests. Defaults to `:info`.","ref":"GSMLG.Logger.Ecto.html#attach/3-available-options","title":"Available options - GSMLG.Logger.Ecto.attach/3","type":"function"},{"doc":"In some cases you may wish to set the log level dynamically\non a per-query basis. To do so, set the `:level` option to\na tuple, `{Mod, Fun, Args}`. The query and map of time measures\nwill be prepended to the provided list of arguments.\n\nWhen invoked, your function must return a\n[`Logger.level()`](`t:Logger.level()/0`) or `false` to\ndisable logging for the request.","ref":"GSMLG.Logger.Ecto.html#attach/3-dynamic-log-level","title":"Dynamic log level - GSMLG.Logger.Ecto.attach/3","type":"function"},{"doc":"Attaching the telemetry handler to the `MyApp.Repo` events with the `:info` log level:\n\n    GSMLG.Logger.Ecto.attach(\"gsmlg-logger-queries\", [:my_app, :repo, :query], :info)\n\nFor more details on event and handler naming see\n(`Ecto.Repo` documentation)[https://hexdocs.pm/ecto/Ecto.Repo.html#module-telemetry-events].","ref":"GSMLG.Logger.Ecto.html#attach/3-examples","title":"Examples - GSMLG.Logger.Ecto.attach/3","type":"function"},{"doc":"A telemetry handler that logs Ecto query along with it's metrics in a structured format.","ref":"GSMLG.Logger.Ecto.html#telemetry_logging_handler/4","title":"GSMLG.Logger.Ecto.telemetry_logging_handler/4","type":"function"},{"doc":"","ref":"GSMLG.Logger.Formatter.html","title":"GSMLG.Logger.Formatter","type":"behaviour"},{"doc":"","ref":"GSMLG.Logger.Formatter.html#c:format/2","title":"GSMLG.Logger.Formatter.format/2","type":"callback"},{"doc":"","ref":"GSMLG.Logger.Formatter.html#t:opts/0","title":"GSMLG.Logger.Formatter.opts/0","type":"type"},{"doc":"","ref":"GSMLG.Logger.Formatter.RedactorEncoder.html","title":"GSMLG.Logger.Formatter.RedactorEncoder","type":"module"},{"doc":"Takes a term and makes sure that it can be encoded by Jason.encode!/1 without errors\nand without leaking sensitive information.","ref":"GSMLG.Logger.Formatter.RedactorEncoder.html#encode/2","title":"GSMLG.Logger.Formatter.RedactorEncoder.encode/2","type":"function"},{"doc":"Type                | Encoding                                            | Redaction\n------------------- | --------------------------------------------------- | --------------\n`boolean()`         | unchanged                                           | unchanged\n`map()`             | unchanged                                           | values are redacted\n`list()`            | unchanged                                           | unchanged\n`tuple()`           | converted to list                                   | unchanged\n`binary()`          | unchanged if printable, otherwise using `inspect/2` | unchanged\n`number()`          | unchanged                                           | unchanged\n`atom()`            | unchanged                                           | unchanged\n`struct()`          | converted to map                                    | values are redacted\n`keyword()`         | converted to map                                    | values are redacted\n`%Jason.Fragment{}` | unchanged                                           | unchanged\neverything else     | using `inspect/2`                                   | unchanged","ref":"GSMLG.Logger.Formatter.RedactorEncoder.html#encode/2-encoding-rules","title":"Encoding rules - GSMLG.Logger.Formatter.RedactorEncoder.encode/2","type":"function"},{"doc":"","ref":"GSMLG.Logger.Formatter.RedactorEncoder.html#t:redactor/0","title":"GSMLG.Logger.Formatter.RedactorEncoder.redactor/0","type":"type"},{"doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a JSON format.\n\nFor list of options see \"Shared options\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.Basic.html","title":"GSMLG.Logger.Formatters.Basic","type":"module"},{"doc":"%{\n      \"message\" => \"Hello\",\n      \"metadata\" => %{\"domain\" => [\"elixir\"]},\n      \"severity\" => \"notice\",\n      \"time\" => \"2024-04-11T21:31:01.403Z\"\n    }","ref":"GSMLG.Logger.Formatters.Basic.html#module-examples","title":"Examples - GSMLG.Logger.Formatters.Basic","type":"module"},{"doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a structured format that can be consumed by Datadog.\n\nThis formatter adheres to the\n[default standard attribute list](https://docs.datadoghq.com/logs/processing/attributes_naming_convention/#default-standard-attribute-list)\nas much as possible.","ref":"GSMLG.Logger.Formatters.Datadog.html","title":"GSMLG.Logger.Formatters.Datadog","type":"module"},{"doc":"The formatter can be configured with the following options:\n\n* `:hostname` (optional) - changes how the `syslog.hostname` is set in logs. By default, it uses `:system` which uses\n  `:inet.gethostname/0` to resolve the value. If you are running in an environment where the hostname is not correct,\n  you can hard code it by setting `hostname` to a string. In places where the hostname is inaccurate but also dynamic\n  (like Kubernetes), you can set `hostname` to `:unset` to exclude it entirely. You'll then be relying on\n  [`dd-agent`](https://docs.datadoghq.com/agent/) to determine the hostname.\n\nFor list of shared options see \"Shared options\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.Datadog.html#module-formatter-configuration","title":"Formatter Configuration - GSMLG.Logger.Formatters.Datadog","type":"module"},{"doc":"For list of other well-known metadata keys see \"Metadata\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.Datadog.html#module-metadata","title":"Metadata - GSMLG.Logger.Formatters.Datadog","type":"module"},{"doc":"%{\n      \"domain\" => [\"elixir\"],\n      \"logger\" => %{\n        \"file_name\" => \"/Users/andrew/Projects/os/gsmlg_logger/test/formatters/datadog_test.exs\",\n        \"line\" => 44,\n        \"method_name\" => \"Elixir.GSMLG.Logger.Formatters.DatadogTest.test logs an LogEntry of a given level/1\",\n        \"thread_name\" => \"#PID<0.234.0>\"\n      },\n      \"message\" => \"Hello\",\n      \"syslog\" => %{\n        \"hostname\" => \"MacBook-Pro\",\n        \"severity\" => \"notice\",\n        \"timestamp\" => \"2024-04-11T23:03:39.726Z\"\n      }\n    }","ref":"GSMLG.Logger.Formatters.Datadog.html#module-examples","title":"Examples - GSMLG.Logger.Formatters.Datadog","type":"module"},{"doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a JSON-structured format that conforms to the Elastic Common Schema (ECS), so it can be consumed by\nElasticSearch, LogStash, FileBeat and Kibana.","ref":"GSMLG.Logger.Formatters.Elastic.html","title":"GSMLG.Logger.Formatters.Elastic","type":"module"},{"doc":"For list of options see \"Shared options\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.Elastic.html#module-formatter-configuration","title":"Formatter Configuration - GSMLG.Logger.Formatters.Elastic","type":"module"},{"doc":"For list of other well-known metadata keys see \"Metadata\" in `GSMLG.Logger`.\n\nAny custom metadata that you set with `Logger.metadata/1` will be included top-level in the log entry.","ref":"GSMLG.Logger.Formatters.Elastic.html#module-metadata","title":"Metadata - GSMLG.Logger.Formatters.Elastic","type":"module"},{"doc":"Example of an info log (`Logger.info(\"Hello\")` without any metadata):\n\n```elixir\n%{\n  \"@timestamp\" => \"2024-05-17T16:20:00.000Z\",\n  \"ecs.version\" => \"8.11.0\",\n  \"log.level\" => \"info\",\n  \"log.logger\" => \"Elixir.GSMLG.Logger.Formatters.ElasticTest\",\n  \"log.origin\" => %{\n    \"file.name\" => \"/app/gsmlg_logger/test/formatters/elastic_test.exs\",\n    \"file.line\" => 18,\n    \"function\" => \"test logs an LogEntry of every level/1\"\n  },\n  \"message\" => \"Hello\"\n}\n```\n\nExample of logging by keywords or by map (Logger.info(%{message: \"Hello\", foo: :bar, fiz: %{buz: \"buz\"}})).\nThe keywords or map items are added to the top-level of the log entry:\n\n```elixir\n%{\n  \"@timestamp\" => \"2024-05-17T16:20:00.000Z\",\n  \"ecs.version\" => \"8.11.0\",\n  \"fiz\" => %{\"buz\" => \"buz\"},\n  \"foo\" => \"bar\",\n  \"log.level\" => \"debug\",\n  \"log.logger\" => \"Elixir.GSMLG.Logger.Formatters.ElasticTest\",\n  \"log.origin\" => %{\n    \"file.line\" => 68,\n    \"file.name\" => \"/app/gsmlg_logger/test/formatters/elastic_test.exs\",\n    \"function\" => \"test logs an LogEntry with a map payload containing message/1\"\n  },\n  \"message\" => \"Hello\"\n}\n```\n\nExample of logging due to raising an exception (`raise RuntimeError`):\n\n```elixir\n%{\n  \"@timestamp\" => \"2024-05-17T16:20:00.000Z\",\n  \"ecs.version\" => \"8.11.0\",\n  \"error.message\" => \"runtime error\",\n  \"error.stack_trace\" => \"** (RuntimeError) runtime error\n    test/gsmlg_logger/formatters/elastic_test.exs:191: anonymous fn/0 in GSMLG.Logger.Formatters.ElasticTest.\"test logs exceptions\"/1\n\",\n  \"error.type\" => \"Elixir.RuntimeError\",\n  \"log.level\" => \"error\",\n  \"message\" => \"Process #PID<0.322.0> raised an exception\n** (RuntimeError) runtime error\n    test/gsmlg_logger/formatters/elastic_test.exs:191: anonymous fn/0 in GSMLG.Logger.Formatters.ElasticTest.\"test logs exceptions\"/1\"\n}\n```\n\nNote that if you raise an exception that contains an `id` or a `code` property, they will be included in the log entry as `error.id` and `error.code` respectively.\n\nExample:\n\n```elixir\ndefmodule TestException do\n  defexception [:message, :id, :code]\nend\n\n...\n\nraise TestException, id: :oops_id, code: 42, message: \"oops!\"\n```\n\nresults in:\n\n```elixir\n%{\n  \"@timestamp\" => \"2024-05-17T16:20:00.000Z\",\n  \"ecs.version\" => \"8.11.0\",\n  \"error.code\" => 42,\n  \"error.id\" => \"oops_id\",\n  \"error.message\" => \"oops!\",\n  \"error.stack_trace\" => \"** (GSMLG.Logger.Formatters.ElasticTest.TestException) oops!\n    test/gsmlg_logger/formatters/elastic_test.exs:223: anonymous fn/0 in GSMLG.Logger.Formatters.ElasticTest.\"test logs exceptions with id and code\"/1\n\",\n  \"error.type\" => \"Elixir.GSMLG.Logger.Formatters.ElasticTest.TestException\",\n  \"log.level\" => \"error\",\n  \"message\" => \"Process #PID<0.325.0> raised an exception\n** (GSMLG.Logger.Formatters.ElasticTest.TestException) oops!\n    test/gsmlg_logger/formatters/elastic_test.exs:223: anonymous fn/0 in GSMLG.Logger.Formatters.ElasticTest.\"test logs exceptions with id and code\"/1\"\n}\n```\n\nYou can also choose to log caught exceptions with a custom message.\nFor example, after catching an exception with `try`/`rescue`:\n\n```elixir\ntry do\n  raise \"oops\"\nrescue\n  e in RuntimeError -> Logger.error(\"Something went wrong\", crash_reason: {e, __STACKTRACE__})\nend\n```\n\nthen you'll get a message like:\n\n```elixir\n%{\n  \"@timestamp\" => \"2024-05-17T16:20:00.000Z\",\n  \"ecs.version\" => \"8.11.0\",\n  \"error.message\" => \"oops\",\n  \"error.stack_trace\" => \"** (RuntimeError) oops\n    test/gsmlg_logger/formatters/elastic_test.exs:421: anonymous fn/0 in GSMLG.Logger.Formatters.ElasticTest.\"test logs caught errors\"/1\n    (gsmlg_logger 6.0.2) test/support/logger_case.ex:16: anonymous fn/1 in GSMLG.Logger.Case.capture_log/2\n    (ex_unit 1.16.3) lib/ex_unit/capture_io.ex:258: ExUnit.CaptureIO.do_with_io/3\n    (ex_unit 1.16.3) lib/ex_unit/capture_io.ex:134: ExUnit.CaptureIO.capture_io/2\n    (gsmlg_logger 6.0.2) test/support/logger_case.ex:15: GSMLG.Logger.Case.capture_log/2\n    test/gsmlg_logger/formatters/elastic_test.exs:419: GSMLG.Logger.Formatters.ElasticTest.\"test logs caught errors\"/1\n    (ex_unit 1.16.3) lib/ex_unit/runner.ex:472: ExUnit.Runner.exec_test/2\n    (stdlib 5.2.3) timer.erl:270: :timer.tc/2\n    (ex_unit 1.16.3) lib/ex_unit/runner.ex:394: anonymous fn/6 in ExUnit.Runner.spawn_test_monitor/4\n\",\n  \"error.type\" => \"Elixir.RuntimeError\",\n  \"log.level\" => \"error\",\n  \"log.logger\" => \"Elixir.GSMLG.Logger.Formatters.ElasticTest\",\n  \"log.origin\" => %{\n    \"file.line\" => 423,\n    \"file.name\" => \"/app/gsmlg_logger/test/gsmlg_logger/formatters/elastic_test.exs\",\n    \"function\" => \"test logs caught errors/1\"\n  },\n  \"message\" => \"Something went wrong\"\n}\n```","ref":"GSMLG.Logger.Formatters.Elastic.html#module-examples","title":"Examples - GSMLG.Logger.Formatters.Elastic","type":"module"},{"doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a structured format that can be consumed by Google Cloud Logger.\n\nEven though the log messages on Google Cloud use [LogEntry](https://cloud.google.com/logging/docs/reference/v2/rest/v2/LogEntry)\nformat, not all the fields are available in the structured payload. The fields that are available can be found in the\n[special fields in structured payloads](https://cloud.google.com/logging/docs/agent/configuration#special_fields_in_structured_payloads).","ref":"GSMLG.Logger.Formatters.GoogleCloud.html","title":"GSMLG.Logger.Formatters.GoogleCloud","type":"module"},{"doc":"The formatter can be configured with the following options:\n\n* `:project_id` (optional) - the Google Cloud project ID. This is required for correctly logging OpenTelemetry trace and\nspan IDs so that they can be linked to the correct trace in Google Cloud Trace.\n\n* `:service_context` (optional) - a map with the following keys:\n  * `:service` - the name of the service that is logging the message. Default: `node()`.\n  * `:version` - the version of the service that is logging the message.\n\nFor list of shared options see \"Shared options\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.GoogleCloud.html#module-formatter-configuration","title":"Formatter Configuration - GSMLG.Logger.Formatters.GoogleCloud","type":"module"},{"doc":"You can extend the log entry with some additional metadata:application\n\n  * `user_id`, `identity_id`, `actor_id`, `account_id` (ordered by precedence) - the ID of the user that is performing the action.\n  It will be included along with the error report for Google Cloud Error Reporting;\n\nFor list of other well-known metadata keys see \"Metadata\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.GoogleCloud.html#module-metadata","title":"Metadata - GSMLG.Logger.Formatters.GoogleCloud","type":"module"},{"doc":"Regular message:\n\n    %{\n      \"logging.googleapis.com/operation\" => %{\"pid\" => \"#PID<0.228.0>\"},\n      \"logging.googleapis.com/sourceLocation\" => %{\n        \"file\" => \"/Users/andrew/Projects/os/gsmlg_logger/test/formatters/google_cloud_test.exs\",\n        \"function\" => \"Elixir.GSMLG.Logger.Formatters.GoogleCloudTest.test logs an LogEntry of a given level/1\",\n        \"line\" => 44\n      },\n      \"message\" => %{\"domain\" => [\"elixir\"], \"message\" => \"Hello\"},\n      \"severity\" => \"NOTICE\",\n      \"time\" => \"2024-04-11T21:32:46.957Z\"\n    }\n\nException message that will be recognized by Google Cloud Error Reporting:\n\n    %{\n      \"httpRequest\" => %{\n        \"protocol\" => \"HTTP/1.1\",\n        \"referer\" => \"http://www.example.com/\",\n        \"remoteIp\" => \"\",\n        \"requestMethod\" => \"PATCH\",\n        \"requestUrl\" => \"http://www.example.com/\",\n        \"status\" => 503,\n        \"userAgent\" => \"Mozilla/5.0\"\n      },\n      \"logging.googleapis.com/operation\" => %{\"pid\" => \"#PID<0.250.0>\"},\n      \"logging.googleapis.com/sourceLocation\" => %{\n        \"file\" => \"/Users/andrew/Projects/os/gsmlg_logger/test/formatters/google_cloud_test.exs\",\n        \"function\" => \"Elixir.GSMLG.Logger.Formatters.GoogleCloudTest.test logs exception http context/1\",\n        \"line\" => 301\n      },\n      \"@type\" => \"type.googleapis.com/google.devtools.clouderrorreporting.v1beta1.ReportedErrorEvent\",\n      \"context\" => %{\n        \"httpRequest\" => %{\n          \"protocol\" => \"HTTP/1.1\",\n          \"referer\" => \"http://www.example.com/\",\n          \"remoteIp\" => \"\",\n          \"requestMethod\" => \"PATCH\",\n          \"requestUrl\" => \"http://www.example.com/\",\n          \"status\" => 503,\n          \"userAgent\" => \"Mozilla/5.0\"\n        },\n        \"reportLocation\" => %{\n          \"filePath\" => \"/Users/andrew/Projects/os/gsmlg_logger/test/formatters/google_cloud_test.exs\",\n          \"functionName\" => \"Elixir.GSMLG.Logger.Formatters.GoogleCloudTest.test logs exception http context/1\",\n          \"lineNumber\" => 301\n        }\n      },\n      \"domain\" => [\"elixir\"],\n      \"message\" => \"Hello\",\n      \"serviceContext\" => %{\"service\" => \"nonode@nohost\"},\n      \"stack_trace\" => \"** (EXIT from #PID<0.250.0>) :foo\",\n      \"severity\" => \"DEBUG\",\n      \"time\" => \"2024-04-11T21:34:53.503Z\"\n    }","ref":"GSMLG.Logger.Formatters.GoogleCloud.html#module-examples","title":"Examples - GSMLG.Logger.Formatters.GoogleCloud","type":"module"},{"doc":"Custom Erlang's [`:logger` formatter](https://www.erlang.org/doc/apps/kernel/logger_chapter.html#formatters) which\nwrites logs in a structured format that can be consumed by `gsmlg.net`.\n\nThis formatter adheres to the `gsmlg.net` project.","ref":"GSMLG.Logger.Formatters.GsmlgNet.html","title":"GSMLG.Logger.Formatters.GsmlgNet","type":"module"},{"doc":"The formatter can be configured with the following options:\n\n* `:planet` (optional) - set the planet of gsmlg.net.\n\nFor list of shared options see \"Shared options\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.GsmlgNet.html#module-formatter-configuration","title":"Formatter Configuration - GSMLG.Logger.Formatters.GsmlgNet","type":"module"},{"doc":"For list of other well-known metadata keys see \"Metadata\" in `GSMLG.Logger`.","ref":"GSMLG.Logger.Formatters.GsmlgNet.html#module-metadata","title":"Metadata - GSMLG.Logger.Formatters.GsmlgNet","type":"module"},{"doc":"%{\n      time: utc_time(meta),\n      level: Atom.to_string(level),\n      message: encode(message, redactors),\n      metadata: encode(take_metadata(meta, metadata_selector), redactors)\n    }","ref":"GSMLG.Logger.Formatters.GsmlgNet.html#module-examples","title":"Examples - GSMLG.Logger.Formatters.GsmlgNet","type":"module"},{"doc":"A telemetry handler that logs request information in JSON format.","ref":"GSMLG.Logger.Plug.html","title":"GSMLG.Logger.Plug","type":"module"},{"doc":"Attaches the telemetry handler to the given event.","ref":"GSMLG.Logger.Plug.html#attach/3","title":"GSMLG.Logger.Plug.attach/3","type":"function"},{"doc":"* `:level` - log level which is used to log requests. Defaults to `:info`.","ref":"GSMLG.Logger.Plug.html#attach/3-available-options","title":"Available options - GSMLG.Logger.Plug.attach/3","type":"function"},{"doc":"In some cases you may wish to set the log level dynamically\non a per-query basis. To do so, set the `:level` option to\na tuple, `{Mod, Fun, Args}`. The query and map of time measures\nwill be prepended to the provided list of arguments.\n\nWhen invoked, your function must return a\n[`Logger.level()`](`t:Logger.level()/0`) or `false` to\ndisable logging for the request.","ref":"GSMLG.Logger.Plug.html#attach/3-dynamic-log-level","title":"Dynamic log level - GSMLG.Logger.Plug.attach/3","type":"function"},{"doc":"Attaching the telemetry handler to the `MyApp.Plug` events with the `:info` log level:\n\n    # in the endpoint\n    plug Plug.Telemetry, event_prefix: [:myapp, :plug]\n\n    # in your application.ex\n    GSMLG.Logger.Plug.attach(\"gsmlg-logger-requests\", [:myapp, :plug, :stop], :info)\n\nTo make plug broadcast those events see [`Plug.Telemetry`](https://hexdocs.pm/plug/Plug.Telemetry.html) documentation.\n\nYou can also attach to the `[:phoenix, :endpoint, :stop]` event to log request latency from Phoenix endpoints:\n\n    GSMLG.Logger.Plug.attach(\"gsmlg-logger-phoenix-requests\", [:phoenix, :endpoint, :stop], :info)","ref":"GSMLG.Logger.Plug.html#attach/3-examples","title":"Examples - GSMLG.Logger.Plug.attach/3","type":"function"},{"doc":"A telemetry handler that logs requests in a structured format.","ref":"GSMLG.Logger.Plug.html#telemetry_logging_handler/4","title":"GSMLG.Logger.Plug.telemetry_logging_handler/4","type":"function"},{"doc":"This module provides a behaviour which allows to redact sensitive information from logs.\n\n*Note*: redactor will not be applied on `Jason.Fragment` structs. For more information\nabout encoding and redacting see `GSMLG.Logger.Formatter.RedactorEncoder.encode/2`.","ref":"GSMLG.Logger.Redactor.html","title":"GSMLG.Logger.Redactor","type":"behaviour"},{"doc":"Takes a key and a value and returns a redacted value.\n\nThis callback will be applied on key-value pairs, like elements of structs, maps or keyword lists.","ref":"GSMLG.Logger.Redactor.html#c:redact/3","title":"GSMLG.Logger.Redactor.redact/3","type":"callback"},{"doc":"A simple redactor which replace the value of the keys with `\"[REDACTED]\"`.\n\nIt takes list of keys to redact as an argument, eg.:\n```elixir\nconfig :logger, :default_handler,\n  formatter: {GSMLG.Logger.Formatters.Basic, redactors: [\n    {GSMLG.Logger.Redactors.RedactKeys, [\"password\"]}\n  ]}\n```\n\nKeep in mind that the key will be converted to binary before sending it to the redactor.","ref":"GSMLG.Logger.Redactors.RedactKeys.html","title":"GSMLG.Logger.Redactors.RedactKeys","type":"module"},{"doc":"","ref":"GSMLG.Logger.Redactors.RedactKeys.html#redact/3","title":"GSMLG.Logger.Redactors.RedactKeys.redact/3","type":"function"}],"producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}